@@ -8,6 +8,7 @@
 
 Calendar={
 	UI:{
+		scrollcount: 0,
 		loading: function(isLoading){
 			if (isLoading){
 				$('#loading').show();
@@ -18,7 +19,7 @@ Calendar={
 		startEventDialog:function(){
 			Calendar.UI.loading(false);
 			$('.tipsy').remove();
-			$('#calendar_holder').fullCalendar('unselect');
+			$('#fullcalendar').fullCalendar('unselect');
 			Calendar.UI.lockTime();
 			$( "#from" ).datepicker({
 				dateFormat : 'dd-mm-yy'
@@ -32,13 +33,7 @@ Calendar={
 			$('#totime').timepicker({
 			    showPeriodLabels: false
 			});
-			$('#category').multiselect({
-					header: false,
-					noneSelectedText: $('#category').attr('title'),
-					selectedList: 2,
-					minWidth:'auto',
-					classes: 'category',
-			});
+			$('#category').multiple_autocomplete({source: categories});
 			Calendar.UI.repeat('init');
 			$('#end').change(function(){
 				Calendar.UI.repeat('end');
@@ -52,12 +47,15 @@ Calendar={
 			$('#advanced_month').change(function(){
 				Calendar.UI.repeat('month');
 			});
+			$( "#event" ).tabs({ selected: 0});
 			$('#event').dialog({
 				width : 500,
+				height: 600,
 				close : function(event, ui) {
 					$(this).dialog('destroy').remove();
 				}
 			});
+			Calendar.UI.Share.init();
 		},
 		newEvent:function(start, end, allday){
 			start = Math.round(start.getTime()/1000);
@@ -69,17 +67,20 @@ Calendar={
 				$('#event').dialog('destroy').remove();
 			}else{
 				Calendar.UI.loading(true);
-				$('#dialog_holder').load(OC.filePath('calendar', 'ajax', 'neweventform.php'), {start:start, end:end, allday:allday?1:0}, Calendar.UI.startEventDialog);
+				$('#dialog_holder').load(OC.filePath('calendar', 'ajax/event', 'new.form.php'), {start:start, end:end, allday:allday?1:0}, Calendar.UI.startEventDialog);
 			}
 		},
 		editEvent:function(calEvent, jsEvent, view){
+			if (calEvent.editable == false || calEvent.source.editable == false) {
+				return;
+			}
 			var id = calEvent.id;
 			if($('#event').dialog('isOpen') == true){
 				// TODO: save event
 				$('#event').dialog('destroy').remove();
 			}else{
 				Calendar.UI.loading(true);
-				$('#dialog_holder').load(OC.filePath('calendar', 'ajax', 'editeventform.php') + '?id=' + id, Calendar.UI.startEventDialog);
+				$('#dialog_holder').load(OC.filePath('calendar', 'ajax/event', 'edit.form.php'), {id: id}, Calendar.UI.startEventDialog);
 			}
 		},
 		submitDeleteEventForm:function(url){
@@ -89,7 +90,7 @@ Calendar={
 			$.post(url, post, function(data){
 					Calendar.UI.loading(false);
 					if(data.status == 'success'){
-						$('#calendar_holder').fullCalendar('removeEvents', $('#event_form input[name=id]').val());
+						$('#fullcalendar').fullCalendar('removeEvents', $('#event_form input[name=id]').val());
 						$('#event').dialog('destroy').remove();
 					} else {
 						$('#errorbox').html(t('calendar', 'Deletion failed'));
@@ -105,43 +106,47 @@ Calendar={
 				function(data){
 					Calendar.UI.loading(false);
 					if(data.status == "error"){
-						var output = missing_field + ": <br />";
-						if(data.title == "true"){
-							output = output + missing_field_title + "<br />";
+						if(data.message) {
+							$('#errorbox').html(data.data.message);
+						} else {
+							var output = missing_field + ": <br />";
+							if(data.title == "true"){
+								output = output + missing_field_title + "<br />";
+							}
+							if(data.cal == "true"){
+								output = output + missing_field_calendar + "<br />";
+							}
+							if(data.from == "true"){
+								output = output + missing_field_fromdate + "<br />";
+							}
+							if(data.fromtime == "true"){
+								output = output + missing_field_fromtime + "<br />";
+							}
+							if(data.to == "true"){
+								output = output + missing_field_todate + "<br />";
+							}
+							if(data.totime == "true"){
+								output = output + missing_field_totime + "<br />";
+							}
+							if(data.endbeforestart == "true"){
+								output = output + missing_field_startsbeforeends + "!<br/>";
+							}
+							if(data.dberror == "true"){
+								output = "There was a database fail!";
+							}
+							$('#errorbox').html(output);
 						}
-						if(data.cal == "true"){
-							output = output + missing_field_calendar + "<br />";
-						}
-						if(data.from == "true"){
-							output = output + missing_field_fromdate + "<br />";
-						}
-						if(data.fromtime == "true"){
-							output = output + missing_field_fromtime + "<br />";
-						}
-						if(data.to == "true"){
-							output = output + missing_field_todate + "<br />";
-						}
-						if(data.totime == "true"){
-							output = output + missing_field_totime + "<br />";
-						}
-						if(data.endbeforestart == "true"){
-							output = output + missing_field_startsbeforeends + "!<br/>";
-						}
-						if(data.dberror == "true"){
-							output = "There was a database fail!";
-						}
-						$("#errorbox").html(output);
 					} else
 					if(data.status == 'success'){
 						$('#event').dialog('destroy').remove();
-						$('#calendar_holder').fullCalendar('refetchEvents');
+						$('#fullcalendar').fullCalendar('refetchEvents');
 					}
 				},"json");
 		},
 		moveEvent:function(event, dayDelta, minuteDelta, allDay, revertFunc){
 			$('.tipsy').remove();
 			Calendar.UI.loading(true);
-			$.post(OC.filePath('calendar', 'ajax', 'moveevent.php'), { id: event.id, dayDelta: dayDelta, minuteDelta: minuteDelta, allDay: allDay?1:0, lastmodified: event.lastmodified},
+			$.post(OC.filePath('calendar', 'ajax/event', 'move.php'), { id: event.id, dayDelta: dayDelta, minuteDelta: minuteDelta, allDay: allDay?1:0, lastmodified: event.lastmodified},
 			function(data) {
 				Calendar.UI.loading(false);
 				if (data.status == 'success'){
@@ -149,14 +154,14 @@ Calendar={
 					console.log("Event moved successfully");
 				}else{
 					revertFunc();
-					$('#calendar_holder').fullCalendar('refetchEvents');
+					$('#fullcalendar').fullCalendar('refetchEvents');
 				}
 			});
 		},
 		resizeEvent:function(event, dayDelta, minuteDelta, revertFunc){
 			$('.tipsy').remove();
 			Calendar.UI.loading(true);
-			$.post(OC.filePath('calendar', 'ajax', 'resizeevent.php'), { id: event.id, dayDelta: dayDelta, minuteDelta: minuteDelta, lastmodified: event.lastmodified},
+			$.post(OC.filePath('calendar', 'ajax/event', 'resize.php'), { id: event.id, dayDelta: dayDelta, minuteDelta: minuteDelta, lastmodified: event.lastmodified},
 			function(data) {
 				Calendar.UI.loading(false);
 				if (data.status == 'success'){
@@ -164,7 +169,7 @@ Calendar={
 					console.log("Event resized successfully");
 				}else{
 					revertFunc();
-					$('#calendar_holder').fullCalendar('refetchEvents');
+					$('#fullcalendar').fullCalendar('refetchEvents');
 				}
 			});
 		},
@@ -187,10 +192,10 @@ Calendar={
 				// Tue 18 October 2011 08:00 - 16:00
 			}
 			var html =
-				'<div class="summary">' + event.title + '</div>' +
+				'<div class="summary">' + escapeHTML(event.title) + '</div>' +
 				'<div class="timespan">' + timespan + '</div>';
 			if (event.description){
-				html += '<div class="description">' + event.description + '</div>';
+				html += '<div class="description">' + escapeHTML(event.description) + '</div>';
 			}
 			return html;
 		},
@@ -214,12 +219,13 @@ Calendar={
 		},
 		initScroll:function(){
 			if(window.addEventListener)
-				document.addEventListener('DOMMouseScroll', Calendar.UI.scrollCalendar);
+				document.addEventListener('DOMMouseScroll', Calendar.UI.scrollCalendar, false);
 			//}else{
 				document.onmousewheel = Calendar.UI.scrollCalendar;
 			//}
 		},
 		scrollCalendar:function(event){
+			$('#fullcalendar').fullCalendar('option', 'height', $(window).height() - $('#controls').height() - $('#header').height() - 15);
 			$('.tipsy').remove();
 			var direction;
 			if(event.detail){
@@ -236,18 +242,24 @@ Calendar={
 					direction = 'down';
 				}
 			}
+			Calendar.UI.scrollcount++;
+			if(Calendar.UI.scrollcount < 5){
+				return;
+			}
+
 			var scroll = $(document).scrollTop(),
 				doc_height = $(document).height(),
 				win_height = $(window).height();
-			if(direction == 'down' && win_height == (doc_height - scroll)){
-				$('#calendar_holder').fullCalendar('next');
+			if(direction == 'down'/* && win_height == (doc_height - scroll)*/){
+				$('#fullcalendar').fullCalendar('next');
 				$(document).scrollTop(0);
 				event.preventDefault();
-			}else if (direction == 'top' && scroll == 0) {
-				$('#calendar_holder').fullCalendar('prev');
+			}else/* if (direction == 'top' && scroll == 0) */{
+				$('#fullcalendar').fullCalendar('prev');
 				$(document).scrollTop(win_height);
 				event.preventDefault();
 			}
+			Calendar.UI.scrollcount = 0;
 		},
 		repeat:function(task){
 			if(task=='init'){
@@ -349,7 +361,7 @@ Calendar={
 					$('#advanced_weekday').css('display', 'block');
 				}
 			}
-			
+
 		},
 		setViewActive: function(view){
 			$('#view input[type="button"]').removeClass('active');
@@ -367,15 +379,21 @@ Calendar={
 			}
 			$('#'+id).addClass('active');
 		},
+		categoriesChanged:function(newcategories){
+			categories = $.map(newcategories, function(v) {return v;});
+			console.log('Calendar categories changed to: ' + categories);
+			$('#category').multiple_autocomplete('option', 'source', categories);
+		},
 		Calendar:{
 			overview:function(){
 				if($('#choosecalendar_dialog').dialog('isOpen') == true){
 					$('#choosecalendar_dialog').dialog('moveToTop');
 				}else{
 					Calendar.UI.loading(true);
-					$('#dialog_holder').load(OC.filePath('calendar', 'ajax', 'choosecalendar.php'), function(){
+					$('#dialog_holder').load(OC.filePath('calendar', 'ajax/calendar', 'overview.php'), function(){
 						$('#choosecalendar_dialog').dialog({
 							width : 600,
+							height: 400,
 							close : function(event, ui) {
 								$(this).dialog('destroy').remove();
 							}
@@ -387,28 +405,28 @@ Calendar={
 			activation:function(checkbox, calendarid)
 			{
 				Calendar.UI.loading(true);
-				$.post(OC.filePath('calendar', 'ajax', 'activation.php'), { calendarid: calendarid, active: checkbox.checked?1:0 },
+				$.post(OC.filePath('calendar', 'ajax/calendar', 'activation.php'), { calendarid: calendarid, active: checkbox.checked?1:0 },
 				  function(data) {
 					Calendar.UI.loading(false);
 					if (data.status == 'success'){
 						checkbox.checked = data.active == 1;
 						if (data.active == 1){
-							$('#calendar_holder').fullCalendar('addEventSource', data.eventSource);
+							$('#fullcalendar').fullCalendar('addEventSource', data.eventSource);
 						}else{
-							$('#calendar_holder').fullCalendar('removeEventSource', data.eventSource.url);
+							$('#fullcalendar').fullCalendar('removeEventSource', data.eventSource.url);
 						}
 					}
 				  });
 			},
 			newCalendar:function(object){
 				var tr = $(document.createElement('tr'))
-					.load(OC.filePath('calendar', 'ajax', 'newcalendar.php'),
+					.load(OC.filePath('calendar', 'ajax/calendar', 'new.form.php'),
 						function(){Calendar.UI.Calendar.colorPicker(this)});
 				$(object).closest('tr').after(tr).hide();
 			},
 			edit:function(object, calendarid){
 				var tr = $(document.createElement('tr'))
-					.load(OC.filePath('calendar', 'ajax', 'editcalendar.php') + "?calendarid="+calendarid,
+					.load(OC.filePath('calendar', 'ajax/calendar', 'edit.form.php'), {calendarid: calendarid},
 						function(){Calendar.UI.Calendar.colorPicker(this)});
 				$(object).closest('tr').after(tr).hide();
 			},
@@ -417,13 +435,17 @@ Calendar={
 				if(check == false){
 					return false;
 				}else{
-					$.post(OC.filePath('calendar', 'ajax', 'deletecalendar.php'), { calendarid: calid},
+					$.post(OC.filePath('calendar', 'ajax/calendar', 'delete.php'), { calendarid: calid},
 					  function(data) {
 						if (data.status == 'success'){
 							var url = 'ajax/events.php?calendar_id='+calid;
-							$('#calendar_holder').fullCalendar('removeEventSource', url);
+							$('#fullcalendar').fullCalendar('removeEventSource', url);
 							$('#choosecalendar_dialog').dialog('destroy').remove();
 							Calendar.UI.Calendar.overview();
+							$('#calendar tr[data-id="'+calid+'"]').fadeOut(400,function(){
+								$('#calendar tr[data-id="'+calid+'"]').remove();
+							});
+							$('#fullcalendar').fullCalendar('refetchEvents');
 						}
 					  });
 				}
@@ -439,21 +461,21 @@ Calendar={
 						$("#displayname_"+calendarid).css('background-color', '#F8F8F8');
 					});
 				}
-				
+
 				var url;
 				if (calendarid == 'new'){
-					url = OC.filePath('calendar', 'ajax', 'createcalendar.php');
+					url = OC.filePath('calendar', 'ajax/calendar', 'new.php');
 				}else{
-					url = OC.filePath('calendar', 'ajax', 'updatecalendar.php');
+					url = OC.filePath('calendar', 'ajax/calendar', 'update.php');
 				}
 				$.post(url, { id: calendarid, name: displayname, active: active, description: description, color: calendarcolor },
 					function(data){
 						if(data.status == 'success'){
 							$(button).closest('tr').prev().html(data.page).show().next().remove();
-							$('#calendar_holder').fullCalendar('removeEventSource', data.eventSource.url);
-							$('#calendar_holder').fullCalendar('addEventSource', data.eventSource);
+							$('#fullcalendar').fullCalendar('removeEventSource', data.eventSource.url);
+							$('#fullcalendar').fullCalendar('addEventSource', data.eventSource);
 							if (calendarid == 'new'){
-								$('#choosecalendar_dialog > table').append('<tr><td colspan="6"><a href="#" onclick="Calendar.UI.Calendar.newCalendar(this);"><input type="button" value="' + newcalendar + '"></a></td></tr>');
+								$('#choosecalendar_dialog > table:first').append('<tr><td colspan="6"><a href="#" onclick="Calendar.UI.Calendar.newCalendar(this);"><input type="button" value="' + newcalendar + '"></a></td></tr>');
 							}
 						}else{
 							$("#displayname_"+calendarid).css('background-color', '#FF2626');
@@ -478,7 +500,7 @@ Calendar={
 					colors[i].label = $(elm).text();
 				});
 				for (var i in colors) {
-					picker.append('<span class="calendar-colorpicker-color ' + (colors[i].color == $(obj).children(":selected").val() ? ' active' : '') + '" rel="' + colors[i].label + '" style="background-color: #' + colors[i].color + ';"></span>');
+					picker.append('<span class="calendar-colorpicker-color ' + (colors[i].color == $(obj).children(":selected").val() ? ' active' : '') + '" rel="' + colors[i].label + '" style="background-color: ' + colors[i].color + ';"></span>');
 				}
 				picker.delegate(".calendar-colorpicker-color", "click", function() {
 					$(obj).val($(this).attr('rel'));
@@ -492,8 +514,127 @@ Calendar={
 					left: -10000
 				});
 			}
+		},
+		Share:{
+			init:function(){
+				var itemShares = [OC.Share.SHARE_TYPE_USER, OC.Share.SHARE_TYPE_GROUP];
+				$('#sharewith').autocomplete({minLength: 2, source: function(search, response) {
+					$.get(OC.filePath('core', 'ajax', 'share.php'), { fetch: 'getShareWith', search: search.term, itemShares: itemShares }, function(result) {
+						if (result.status == 'success' && result.data.length > 0) {
+							response(result.data);
+						}
+					});
+				},
+				focus: function(event, focused) {
+					event.preventDefault();
+				},
+				select: function(event, selected) {
+					var itemType = 'event';
+					var itemSource = $('#sharewith').data('item-source');
+					var shareType = selected.item.value.shareType;
+					var shareWith = selected.item.value.shareWith;
+					$(this).val(shareWith);
+					// Default permissions are Read and Share
+					var permissions = OC.PERMISSION_READ | OC.PERMISSION_SHARE;
+					OC.Share.share(itemType, itemSource, shareType, shareWith, permissions, function(data) {
+						var newitem = '<li data-item-type="event"'
+							+ 'data-share-with="'+shareWith+'" '
+							+ 'data-permissions="'+permissions+'" '
+							+ 'data-share-type="'+shareType+'">'+shareWith+' ('+(shareType == OC.Share.SHARE_TYPE_USER ? t('core', 'user') : t('core', 'group'))+')'
+							+ '<span class="shareactions"><input class="update" type="checkbox" title="'+t('core', 'Editable')+'">'
+							+ '<input class="share" type="checkbox" title="'+t('core', 'Shareable')+'" checked="checked">'
+							+ '<input class="delete" type="checkbox" title="'+t('core', 'Deletable')+'">'
+							+ '<img class="svg action delete" title="Unshare"src="'+ OC.imagePath('core', 'actions/delete.svg') +'"></span></li>';
+						$('.sharedby.eventlist').append(newitem);
+						$('#sharedWithNobody').remove();
+						$('#sharewith').val('');
+					});
+					return false;
+				}
+				});
+
+				$('.shareactions > input:checkbox').change(function() {
+					var container = $(this).parents('li').first();
+					var permissions = parseInt(container.data('permissions'));
+					var itemType = container.data('item-type');
+					var shareType = container.data('share-type');
+					var itemSource = container.data('item');
+					var shareWith = container.data('share-with');
+					var permission = null;
+					if($(this).hasClass('update')) {
+						permission = OC.PERMISSION_UPDATE;
+					} else if($(this).hasClass('share')) {
+						permission = OC.PERMISSION_SHARE;
+					} else if($(this).hasClass('delete')) {
+						permission = OC.PERMISSION_DELETE;
+					}
+					// This is probably not the right way, but it works :-P
+					if($(this).is(':checked')) {
+						permissions += permission;
+					} else {
+						permissions -= permission;
+					}
+					OC.Share.setPermissions(itemType, itemSource, shareType, shareWith, permissions);
+				});
+
+				$('.shareactions > .delete').click(function() {
+					var container = $(this).parents('li').first();
+					var itemType = container.data('item-type');
+					var shareType = container.data('share-type');
+					var itemSource = container.data('item');
+					var shareWith = container.data('share-with');
+					OC.Share.unshare(itemType, itemSource, shareType, shareWith, function() {
+						container.remove();
+					});
+				});
+			}
+		},
+		Drop:{
+			init:function(){
+				if (typeof window.FileReader === 'undefined') {
+					console.log('The drop-import feature is not supported in your browser :(');
+					return false;
+				}
+				droparea = document.getElementById('fullcalendar');
+				droparea.ondrop = function(e){
+					e.preventDefault();
+					Calendar.UI.Drop.drop(e);
+				}
+				console.log('Drop initialized successfully');
+			},
+			drop:function(e){
+				var files = e.dataTransfer.files;
+				for(var i = 0;i < files.length;i++){
+					var file = files[i];
+					reader = new FileReader();
+					reader.onload = function(event){
+						Calendar.UI.Drop.import(event.target.result);
+						$('#fullcalendar').fullCalendar('refetchEvents');
+					}
+					reader.readAsDataURL(file);
+				}
+			},
+			import:function(data){
+				$.post(OC.filePath('calendar', 'ajax/import', 'dropimport.php'), {'data':data},function(result) {
+					if(result.status == 'success'){
+						$('#fullcalendar').fullCalendar('addEventSource', result.eventSource);
+						$('#notification').html(result.message);
+						$('#notification').slideDown();
+						window.setTimeout(function(){$('#notification').slideUp();}, 5000);
+						return true;
+					}else{
+						$('#notification').html(result.message);
+						$('#notification').slideDown();
+						window.setTimeout(function(){$('#notification').slideUp();}, 5000);
+					}
+				});
+			}
 		}
-	}
+	},
+	Settings:{
+		//
+	},
+
 }
 $.fullCalendar.views.list = ListView;
 function ListView(element, calendar) {
@@ -548,10 +689,12 @@ function ListView(element, calendar) {
 		if (delta) {
 			if (delta < 0){
 				addDays(t.start, -7);
+				addDays(t.end, -7);
 				if (!opt('weekends')) {
 					skipWeekend(t.start, delta < 0 ? -1 : 1);
 				}
 			}else{
+				addDays(t.start, 7);
 				addDays(t.end, 7);
 				if (!opt('weekends')) {
 					skipWeekend(t.end, delta < 0 ? -1 : 1);
@@ -603,7 +746,7 @@ function ListView(element, calendar) {
 			' class="' + classes.join(' ') + '"' +
 			'>' +
 			'<span class="fc-event-title">' +
-			event.title +
+			escapeHTML(event.title) +
 			'</span>' +
 			'</span>' +
 			'</td>' +
@@ -659,17 +802,27 @@ function ListView(element, calendar) {
 }
 $(document).ready(function(){
 	Calendar.UI.initScroll();
-	$('#calendar_holder').fullCalendar({
+	$('#fullcalendar').fullCalendar({
 		header: false,
-		firstDay: 1,
+		firstDay: firstDay,
 		editable: true,
 		defaultView: defaultView,
 		timeFormat: {
 			agenda: agendatime,
 			'': defaulttime
 			},
+		columnFormat: {
+			month: t('calendar', 'ddd'),    // Mon
+			week: t('calendar', 'ddd M/d'), // Mon 9/7
+			day: t('calendar', 'dddd M/d')  // Monday 9/7
+			},
 		titleFormat: {
-			list: 'yyyy/MMM/d dddd'
+			month: t('calendar', 'MMMM yyyy'),
+					// September 2009
+			week: t('calendar', "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}"),
+					// Sep 7 - 13 2009
+			day: t('calendar', 'dddd, MMM d, yyyy'),
+					// Tuesday, Sep 8, 2009
 			},
 		axisFormat: defaulttime,
 		monthNames: monthNames,
@@ -678,15 +831,19 @@ $(document).ready(function(){
 		dayNamesShort: dayNamesShort,
 		allDayText: allDayText,
 		viewDisplay: function(view) {
-			$('#datecontrol_date').html(view.title);
-			$.get(OC.filePath('calendar', 'ajax', 'changeview.php') + "?v="+view.name);
+			$('#datecontrol_date').val($('<p>').html(view.title).text());
+			if (view.name != defaultView) {
+				$.post(OC.filePath('calendar', 'ajax', 'changeview.php'), {v:view.name});
+				defaultView = view.name;
+			}
 			Calendar.UI.setViewActive(view.name);
 			if (view.name == 'agendaWeek') {
-				$('#calendar_holder').fullCalendar('option', 'aspectRatio', 0.1);
+				$('#fullcalendar').fullCalendar('option', 'aspectRatio', 0.1);
 			}
 			else {
-				$('#calendar_holder').fullCalendar('option', 'aspectRatio', 1.35);
+				$('#fullcalendar').fullCalendar('option', 'aspectRatio', 1.35);
 			}
+			$('#fullcalendar').fullCalendar('rerenderEvents');
 		},
 		columnFormat: {
 		    week: 'ddd d. MMM'
@@ -710,25 +867,60 @@ $(document).ready(function(){
 				}
 			});
 		},
+		eventAfterRender: function(event, element, view) {
+			if(view.name == 'agendaWeek'){
+				element.find('.fc-event-title').html(element.find('.fc-event-title').text());
+			}
+		},
 		loading: Calendar.UI.loading,
 		eventSources: eventSources
 	});
+	$('#datecontrol_date').datepicker({
+		changeMonth: true,
+		changeYear: true,
+		showButtonPanel: true,
+		beforeShow: function(input, inst) {
+			var calendar_holder = $('#fullcalendar');
+			var date = calendar_holder.fullCalendar('getDate');
+			inst.input.datepicker('setDate', date);
+			inst.input.val(calendar_holder.fullCalendar('getView').title);
+			return inst;
+		},
+		onSelect: function(value, inst) {
+			var date = inst.input.datepicker('getDate');
+			$('#fullcalendar').fullCalendar('gotoDate', date);
+		}
+	});
+	fillWindow($('#content'));
+	OCCategories.changed = Calendar.UI.categoriesChanged;
+	OCCategories.app = 'calendar';
 	$('#oneweekview_radio').click(function(){
-		$('#calendar_holder').fullCalendar('changeView', 'agendaWeek');
+		$('#fullcalendar').fullCalendar('changeView', 'agendaWeek');
 	});
 	$('#onemonthview_radio').click(function(){
-		$('#calendar_holder').fullCalendar('changeView', 'month');
+		$('#fullcalendar').fullCalendar('changeView', 'month');
 	});
 	$('#listview_radio').click(function(){
-		$('#calendar_holder').fullCalendar('changeView', 'list');
+		$('#fullcalendar').fullCalendar('changeView', 'list');
 	});
 	$('#today_input').click(function(){
-		$('#calendar_holder').fullCalendar('today');
+		$('#fullcalendar').fullCalendar('today');
 	});
 	$('#datecontrol_left').click(function(){
-		$('#calendar_holder').fullCalendar('prev');
+		$('#fullcalendar').fullCalendar('prev');
 	});
 	$('#datecontrol_right').click(function(){
-		$('#calendar_holder').fullCalendar('next');
+		$('#fullcalendar').fullCalendar('next');
 	});
+	Calendar.UI.Share.init();
+	Calendar.UI.Drop.init();
+	$('#choosecalendar .generalsettings').on('click keydown', function(event) {
+		event.preventDefault();
+		OC.appSettings({appid:'calendar', loadJS:true, cache:false});
+	});
+	$('#choosecalendar .calendarsettings').on('click keydown', function(event) {
+		event.preventDefault();
+		OC.appSettings({appid:'calendar', loadJS:true, cache:false, scriptName:'calendar.php'});
+	});
+	$('#fullcalendar').fullCalendar('option', 'height', $(window).height() - $('#controls').height() - $('#header').height() - 15);
 });
