@@ -1,12 +1,12 @@
 <?php $TRANSLATIONS = array(
+"Information about vCard is incorrect. Please reload the page." => "Подаци о вКарти су неисправни. Поново учитајте страницу.",
 "Contacts" => "Контакти",
+"Download" => "Преузимање",
+"Edit" => "Уреди",
+"Delete" => "Обриши",
+"Cancel" => "Откажи",
 "This is not your addressbook." => "Ово није ваш адресар.",
 "Contact could not be found." => "Контакт се не може наћи.",
-"Information about vCard is incorrect. Please reload the page." => "Подаци о вКарти су неисправни. Поново учитајте страницу.",
-"Address" => "Адреса",
-"Telephone" => "Телефон",
-"Email" => "Е-маил",
-"Organization" => "Организација",
 "Work" => "Посао",
 "Home" => "Кућа",
 "Mobile" => "Мобилни",
@@ -15,38 +15,25 @@
 "Fax" => "Факс",
 "Video" => "Видео",
 "Pager" => "Пејџер",
+"Birthday" => "Рођендан",
 "Contact" => "Контакт",
-"This is not your contact." => "Ово није ваш контакт.",
 "Add Contact" => "Додај контакт",
-"Addressbooks" => "Адресар",
-"Addressbook" => "Адресар",
-"Name" => "Име",
+"Organization" => "Организација",
+"Preferred" => "Пожељан",
+"Phone" => "Телефон",
+"Email" => "Е-маил",
+"Address" => "Адреса",
+"Download contact" => "Преузми контакт",
+"Delete contact" => "Обриши контакт",
 "Type" => "Тип",
 "PO Box" => "Поштански број",
 "Extended" => "Прошири",
-"Street" => "Улица",
 "City" => "Град",
 "Region" => "Регија",
 "Zipcode" => "Зип код",
 "Country" => "Земља",
-"Create Contact" => "Направи контакт",
-"Choose active Address Books" => "Изаберите активне адресаре",
+"Addressbook" => "Адресар",
+"Addressbooks" => "Адресар",
 "New Address Book" => "Нови адресар",
-"Download" => "Преузимање",
-"Edit" => "Уреди",
-"Delete" => "Обриши",
-"Download contact" => "Преузми контакт",
-"Delete contact" => "Обриши контакт",
-"Add" => "Додај",
-"New Addressbook" => "Нови адресар",
-"Edit Addressbook" => "Уреди адресар",
-"Displayname" => "Приказано име",
-"Active" => "Активан",
-"Save" => "Сними",
-"Submit" => "Пошаљи",
-"Cancel" => "Откажи",
-"Birthday" => "Рођендан",
-"Preferred" => "Пожељан",
-"Phone" => "Телефон",
-"Update" => "Ажурирај"
+"Save" => "Сними"
 );
