@@ -1,6 +1,9 @@
 <?php $TRANSLATIONS = array(
 "Music" => "Muzică",
-"Play" => "Play",
+"songs" => "melodii",
+"albums" => "albume",
+"Add album to playlist" => "Adaugă albumul la lista de redare",
+"Play" => "Redă",
 "Pause" => "Pauză",
 "Previous" => "Precedent",
 "Next" => "Următor",
