@@ -1,12 +1,13 @@
 <?php $TRANSLATIONS = array(
 "Music" => "Glasba",
+"Add album to playlist" => "Dodaj album na seznam predvajanja",
 "Play" => "Predvajaj",
-"Pause" => "Pavza",
+"Pause" => "Premor",
 "Previous" => "Prejšnja",
 "Next" => "Naslednja",
-"Mute" => "Izključi zvok",
-"Unmute" => "Vključi zvok",
-"Rescan Collection" => "Skeniraj zbirko",
+"Mute" => "Utišaj",
+"Unmute" => "Povrni glasnost",
+"Rescan Collection" => "Ponovno preišči zbirko",
 "Artist" => "Izvajalec",
 "Album" => "Album",
 "Title" => "Naslov"
