@@ -21,24 +21,24 @@
 *
 */
 
-require_once('apps/user_ldap/user_ldap.php');
+OCP\App::registerAdmin('user_ldap', 'settings');
 
-OC_APP::registerAdmin('user_ldap','settings');
-
-// define LDAP_DEFAULT_PORT
-define('OC_USER_BACKEND_LDAP_DEFAULT_PORT', 389);
-
-// define OC_USER_BACKEND_LDAP_DEFAULT_DISPLAY_NAME
-define('OC_USER_BACKEND_LDAP_DEFAULT_DISPLAY_NAME', 'uid');
+$connector = new OCA\user_ldap\lib\Connection('user_ldap');
+$userBackend  = new OCA\user_ldap\USER_LDAP();
+$userBackend->setConnector($connector);
+$groupBackend = new OCA\user_ldap\GROUP_LDAP();
+$groupBackend->setConnector($connector);
 
 // register user backend
-OC_User::useBackend( "LDAP" );
+OC_User::useBackend($userBackend);
+OC_Group::useBackend($groupBackend);
 
 // add settings page to navigation
 $entry = array(
-	'id' => "user_ldap_settings",
+	'id' => 'user_ldap_settings',
 	'order'=>1,
-	'href' => OC_Helper::linkTo( "user_ldap", "settings.php" ),
+	'href' => OCP\Util::linkTo( 'user_ldap', 'settings.php' ),
 	'name' => 'LDAP'
 );
-// OC_App::addNavigationSubEntry( "core_users", $entry);
+
+OCP\Backgroundjob::addRegularTask('OCA\user_ldap\lib\Jobs', 'updateGroups');
