@@ -22,11 +22,10 @@
 */
 
 // Init owncloud
-require_once('../../lib/base.php');
+require_once '../../lib/base.php';
 
 $app = $_POST["app"];
 
-$l = new OC_L10N( $app );
+$l = OC_L10N::get( $app );
 
 OC_JSON::success(array('data' => $l->getTranslations()));
-?>
